__all__ = [
    "ABADON_SDK_VERSION",
    "ABADON_LIB_ROUTE_HEADER",
    "ABADON_LIB_SEND_MSG",
    "ABADON_LIB_SERVER_HOST",
    "ABADON_LIB_GET_RUNNING_ID"
]

ABADON_SDK_VERSION = "v0.1.3"

ABADON_LIB_SERVER_HOST = "http://0.0.0.0:6875"
ABADON_LIB_ROUTE_HEADER = "/http_api/v0.0.1"
ABADON_LIB_SEND_MSG = "/event/msg"
ABADON_LIB_GET_RUNNING_ID = "/event/running_id"
